@@ -73,7 +73,7 @@ class IngressAdapter:
         raise NotImplementedError
 
     @abc.abstractmethod
-    def save_state(self) -> Optional[bytes]:
+    def save_state(self):
         """
         Save the state for next run. This method is first called after successful upload.
         """
@@ -119,6 +119,9 @@ class IngressAdapter:
         try:
             self.ingress.upload_json_file(file, schema_validate)
             self.save_state()
+        except NotImplementedError:
+            logger.error('Method save_state NotImplementedError')
+            sys.exit(-1)
         except Exception as error:  # pylint: disable=broad-except
             logger.error('Exception occurred while running upload_json_data: %s', str(error))
             sys.exit(-1)
@@ -139,6 +142,9 @@ class IngressAdapter:
         try:
             self.ingress.upload_file(file)
             self.save_state()
+        except NotImplementedError:
+            logger.error('Method save_state NotImplementedError')
+            sys.exit(-1)
         except Exception as error:  # pylint: disable=broad-except
             logger.error('Exception occurred while running upload_data: %s', str(error))
             sys.exit(-1)
@@ -159,6 +165,10 @@ class IngressAdapter:
 
         try:
             self.ingress.upload_json_file_event_time(file, self.get_event_time(), schema_validate)
+            self.save_state()
+        except NotImplementedError:
+            logger.error('Method save_state NotImplementedError')
+            sys.exit(-1)
         except Exception as error:  # pylint: disable=broad-except
             logger.error('Exception occurred while running upload_json_data: %s', str(error))
             sys.exit(-1)
@@ -178,6 +188,10 @@ class IngressAdapter:
 
         try:
             self.ingress.upload_file_event_time(file, self.get_event_time())
+            self.save_state()
+        except NotImplementedError:
+            logger.error('Method save_state NotImplementedError')
+            sys.exit(-1)
         except Exception as error:  # pylint: disable=broad-except
             logger.error('Exception occurred while running upload_data: %s', str(error))
             sys.exit(-1)
